function s=latextext(x, y, string)
%
%  Funktion  s=latextext(x, y, string)
%
%  Hilfsfunktion für die Erzeugung von Latex-Texten in Bildern
%      x - x-Position des Textbeginns
%      y - y-Position des Textbeginns
%    string - mit Latex-Notation geschriebener Text, in '...' eingerahmt,
%             darin vorkommender mathematischer Text in $$...$$ eingerahmt
%
% J. Lunze  
% für 3. Auflage: 6.1.2012
text('Interpreter','latex',...
	'String',string,...
	'Position',[x, y],...
    'FontName','times',...
	'FontSize',14)

% text('Interpreter','latex',...
% 	'String','$$string$$',...
% 	'Position',[x, y],...
% 	'FontSize',14)